@@ -70,10 +70,13 @@ def build_and_publish():
         last_release_version = version.parse(last_release_str)
 
         # Fail if current version <= last release
-        if current_version <= last_release_version:
+        if current_version == last_release_version:
+            console.print(f"[yellow]No new release. Current version: {current_version_str}[/]")
+            sys.exit(1)
+        elif current_version < last_release_version:
             console.print(
                 f"[red]Error:[/] Current version {current_version_str} must "
-                f"be greater than last release {last_release_str}"
+                f"be equal or greater than last release {last_release_str}"
             )
             sys.exit(1)
     else:
