@@ -188,21 +188,6 @@ def load_file_content(workspace_path: str) -> str:
     return full_path.read_text()
 
 
-def load_file_content_safe(workspace_path: str) -> str:
-    """Load file content with error handling, returning error message on failure.
-
-    Args:
-        workspace_path: Path relative to workspace root
-
-    Returns:
-        Content of the file as string, or error message if file cannot be read
-    """
-    try:
-        return load_file_content(workspace_path)
-    except (WorkspaceError, OSError) as e:
-        return f"Error loading {workspace_path}: {str(e)}"
-
-
 def package_root() -> Path:
     """Get the root directory of the package."""
     return importlib.resources.files("ai_kit")
